smartcard.CardConnectionObserver.CardConnectionObserver

# ``smartcard`.`CardConnectionObserver`.`CardConnectionObserver``

class documentation

`class CardConnectionObserver(Observer):`

Known subclasses: `smartcard.CardConnectionObserver.ConsoleCardConnectionObserver`, `smartcard.wx.APDUTracerPanel.APDUTracerPanel`

View In Hierarchy

CardConnectionObserver is a base class for objects that are to be notified upon `CardConnection` events.

Method | `update` | Called upon CardConnection event.

def update(self, cardconnection, cardconnectionevent):
overrides `smartcard.Observer.Observer.update`
overridden in `smartcard.CardConnectionObserver.ConsoleCardConnectionObserver`, `smartcard.wx.APDUTracerPanel.APDUTracerPanel`

Called upon CardConnection event.

Parameters
cardconnection | the observed card connection object
cardconnectionevent | the CardConnectionEvent sent by the connection